# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`comptoir`](#comptoir): Deploy and configure Comptoir-du-Libre webapp

## Classes

### <a name="comptoir"></a>`comptoir`

Deploy and configure Comptoir-du-Libre webapp.

#### Examples

##### 

```puppet
class { 'comptoir':
  trusted_hosts     => '^example\.org$|^comptoir\.example\.org$',
  sys_rootpath      => '/var/www/comptoir.example.org',
  sys_rootpath_mode => '0700',
  sys_user          => 'www-data',
  sys_group         => 'www-data',
}
```

#### Parameters

The following parameters are available in the `comptoir` class:

* [`download_url`](#-comptoir--download_url)
* [`download_checksum`](#-comptoir--download_checksum)
* [`checksum_type`](#-comptoir--checksum_type)
* [`app_default_uri`](#-comptoir--app_default_uri)
* [`app_name`](#-comptoir--app_name)
* [`app_shortname`](#-comptoir--app_shortname)
* [`app_session_lifetime`](#-comptoir--app_session_lifetime)
* [`app_reset_password_token_lifetime`](#-comptoir--app_reset_password_token_lifetime)
* [`app_user_min_password_lenght`](#-comptoir--app_user_min_password_lenght)
* [`app_version_displayed_publicly`](#-comptoir--app_version_displayed_publicly)
* [`app_secret`](#-comptoir--app_secret)
* [`config_path`](#-comptoir--config_path)
* [`var_path`](#-comptoir--var_path)
* [`trusted_hosts`](#-comptoir--trusted_hosts)
* [`timezone`](#-comptoir--timezone)
* [`i18ndefaultlocale`](#-comptoir--i18ndefaultlocale)
* [`sys_usermanage`](#-comptoir--sys_usermanage)
* [`sys_user`](#-comptoir--sys_user)
* [`sys_group`](#-comptoir--sys_group)
* [`sys_rootpath`](#-comptoir--sys_rootpath)
* [`sys_rootpath_mode`](#-comptoir--sys_rootpath_mode)
* [`db_manage`](#-comptoir--db_manage)
* [`db_host`](#-comptoir--db_host)
* [`db_version`](#-comptoir--db_version)
* [`db_user`](#-comptoir--db_user)
* [`db_password`](#-comptoir--db_password)
* [`db_name`](#-comptoir--db_name)
* [`smtp_host`](#-comptoir--smtp_host)
* [`smtp_port`](#-comptoir--smtp_port)
* [`smtp_user`](#-comptoir--smtp_user)
* [`smtp_password`](#-comptoir--smtp_password)
* [`smtp_mailfrom`](#-comptoir--smtp_mailfrom)
* [`smtp_mailalertingto`](#-comptoir--smtp_mailalertingto)

##### <a name="-comptoir--download_url"></a>`download_url`

Data type: `Stdlib::HTTPSUrl`

URL where Comptoir-du-Libre archive is stored.

Default value: `'https://gitlab.adullact.net/Comptoir/comptoir-du-libre/-/package_files/1056/download'`

##### <a name="-comptoir--download_checksum"></a>`download_checksum`

Data type: `String[1]`

Archive file checksum (match checksum_type) used to verify of archive file.

Default value: `'f33363b96fc330b9298d3477f90ee1aaa09eb06605901b72af3d472c054cf223'`

##### <a name="-comptoir--checksum_type"></a>`checksum_type`

Data type: `Enum['md5', 'sha1', 'sha2', 'sha256', 'sha384', 'sha512']`

Checksum type given with download_checksum.

Default value: `'sha256'`

##### <a name="-comptoir--app_default_uri"></a>`app_default_uri`

Data type: `Stdlib::HTTPUrl`

Default URI used to generate URLs in a non-HTTP context

Default value: `'https://comptoir.example.org/'`

##### <a name="-comptoir--app_name"></a>`app_name`

Data type: `String[1]`

A custom string displayed to users as name of service.

Default value: `'Comptoir-du-Libre'`

##### <a name="-comptoir--app_shortname"></a>`app_shortname`

Data type: `String[1]`

A custom string displayed to users as short name of service.

Default value: `'Comptoir'`

##### <a name="-comptoir--app_session_lifetime"></a>`app_session_lifetime`

Data type: `Integer`

Lifetime of webapp session in seconds

Default value: `3600`

##### <a name="-comptoir--app_reset_password_token_lifetime"></a>`app_reset_password_token_lifetime`

Data type: `Integer`

Lifetime of reset password token in seconds

Default value: `1500`

##### <a name="-comptoir--app_user_min_password_lenght"></a>`app_user_min_password_lenght`

Data type: `Integer`

Minimum user password length

Default value: `12`

##### <a name="-comptoir--app_version_displayed_publicly"></a>`app_version_displayed_publicly`

Data type: `Boolean`

Public display of software version

Default value: `false`

##### <a name="-comptoir--app_secret"></a>`app_secret`

Data type: `String[1]`

Application secret is required to generate CSRF tokens

Default value: `'ThisTokenIsNotSoSecretChangeIt'`

##### <a name="-comptoir--config_path"></a>`config_path`

Data type: `Stdlib::Absolutepath`

Directory where Comptoir-du-Libre configuration file is stored.

Default value: `'/etc/comptoir'`

##### <a name="-comptoir--var_path"></a>`var_path`

Data type: `Stdlib::Absolutepath`

Directory where Comptoir-du-Libre stores var files.

Default value: `'/var/comptoir'`

##### <a name="-comptoir--trusted_hosts"></a>`trusted_hosts`

Data type: `String[1]`

Regular expression listing allowed domains and IP to prevent HTTP Host header attacks

Default value: `$facts['networking']['fqdn']`

##### <a name="-comptoir--timezone"></a>`timezone`

Data type: `String[1]`

Time Zone used by Comptoir-du-Libre web application

Default value: `'Europe/Paris'`

##### <a name="-comptoir--i18ndefaultlocale"></a>`i18ndefaultlocale`

Data type: `Enum['en','fr']`

Default language used by Comptoir-du-Libre in WebUI.

Default value: `'en'`

##### <a name="-comptoir--sys_usermanage"></a>`sys_usermanage`

Data type: `Boolean`

To enable/disable the creation of system user and group. To permit manage then by external process.

Default value: `true`

##### <a name="-comptoir--sys_user"></a>`sys_user`

Data type: `String[1]`

Operating system user account owner of Comptoir-du-Libre files

Default value: `'comptoir'`

##### <a name="-comptoir--sys_group"></a>`sys_group`

Data type: `String[1]`

Operating system group owner of Comptoir-du-Libre files

Default value: `'comptoir'`

##### <a name="-comptoir--sys_rootpath"></a>`sys_rootpath`

Data type: `Stdlib::Absolutepath`

Path where Comptoir-du-Libre is installed

Default value: `'/opt/comptoir'`

##### <a name="-comptoir--sys_rootpath_mode"></a>`sys_rootpath_mode`

Data type: `String`

Unix mode set to path defined by $sys_rootpath

Default value: `'0750'`

##### <a name="-comptoir--db_manage"></a>`db_manage`

Data type: `Boolean`

To enable/disable installation of local PostgreSQl server, creation of role and database. To permit manage then by external process.

Default value: `true`

##### <a name="-comptoir--db_host"></a>`db_host`

Data type: `Stdlib::Host`

PostgreSQL server to use

Default value: `'127.0.0.1'`

##### <a name="-comptoir--db_version"></a>`db_version`

Data type: `String[1]`

Version of PostgreSQL server

Default value: `'14'`

##### <a name="-comptoir--db_user"></a>`db_user`

Data type: `String[1]`

Database user used to connect PostgreSQL server

Default value: `'dbcomptoir'`

##### <a name="-comptoir--db_password"></a>`db_password`

Data type: `Variant[String[1], Sensitive[String]]`

Database password used to connect PostgreSQL server

Default value: `Sensitive.new('changeit')`

##### <a name="-comptoir--db_name"></a>`db_name`

Data type: `String[1]`

Database name used by Comptoir-du-Libre

Default value: `'comptoir'`

##### <a name="-comptoir--smtp_host"></a>`smtp_host`

Data type: `Stdlib::Host`

SMTP host to use

Default value: `'127.0.0.1'`

##### <a name="-comptoir--smtp_port"></a>`smtp_port`

Data type: `Stdlib::Port`

SMTP port to use

Default value: `25`

##### <a name="-comptoir--smtp_user"></a>`smtp_user`

Data type: `Optional[String[1]]`

SMTP user used with SMTP auth. If user is email, use username%40example.org instead of username@example.org.

Default value: `undef`

##### <a name="-comptoir--smtp_password"></a>`smtp_password`

Data type: `Optional[Variant[String[1], Sensitive[String]]]`

SMTP password used with SMTP auth

Default value: `undef`

##### <a name="-comptoir--smtp_mailfrom"></a>`smtp_mailfrom`

Data type: `Stdlib::Email`

Who the email sent by Comptoir-du-Libre should come from.

Default value: `"admin@${facts['networking']['domain']}"`

##### <a name="-comptoir--smtp_mailalertingto"></a>`smtp_mailalertingto`

Data type: `Stdlib::Email`

Email address for alert notifications (web application not working properly, ...)

Default value: `"monitor@${facts['networking']['domain']}"`

